import { Logger } from "@smithy/types";
import { SsoProfile } from "./types";
/**
 * @internal
 */
export declare const validateSsoProfile: (profile: Partial<SsoProfile>, logger?: Logger) => SsoProfile;
